@@ -8,11 +8,11 @@
 #ifndef ATTICA_ATTICABASEJOB_H
 #define ATTICA_ATTICABASEJOB_H
 
+#include <QNetworkAccessManager>
+#include <QNetworkRequest>
 #include <QObject>
 #include <QSharedPointer>
 #include <QUrl>
-#include <QNetworkAccessManager>
-#include <QNetworkRequest>
 
 #include "attica_export.h"
 #include "metadata.h"
@@ -23,20 +23,32 @@ namespace Attica
 {
 class PlatformDependent;
 
+/**
+ * @class BaseJob atticabasejob.h
+ *
+ * The baseclass for all job classes.
+ */
 class ATTICA_EXPORT BaseJob : public QObject
 {
     Q_OBJECT
 
 public:
-    virtual ~BaseJob();
+    ~BaseJob() override;
 
     Metadata metadata() const;
 
     enum NetworkRequestCustomAttributes {
         UserAttribute = QNetworkRequest::User + 1,
-        PasswordAttribute
+        PasswordAttribute,
     };
 
+    /**
+     * @returns whether abort() has been called on the job
+     *
+     * @since 5.87
+     */
+    bool isAborted() const;
+
 public Q_SLOTS:
     void start();
     void abort();
