@@ -12,17 +12,16 @@
 #include "attica_debug.h"
 #include "atticautils.h"
 
+#include <QAuthenticator>
 #include <QCoreApplication>
 #include <QDebug>
 #include <QFile>
+#include <QNetworkProxy>
 #include <QPluginLoader>
 #include <QSet>
-#include <QTimer>
-#include <QProcess>
-#include <QAuthenticator>
-#include <QNetworkProxy>
-#include <QXmlStreamReader>
 #include <QSignalMapper>
+#include <QTimer>
+#include <QXmlStreamReader>
 
 #include "platformdependent.h"
 #include "qtplatformdependent_p.h"
@@ -30,7 +29,7 @@
 
 using namespace Attica;
 
-class ProviderManager::Private
+class Q_DECL_HIDDEN ProviderManager::Private
 {
 public:
     PlatformDependent *m_internals;
@@ -57,7 +56,7 @@ PlatformDependent *ProviderManager::loadPlatformDependent(const ProviderFlags &f
     }
 
     QPluginLoader loader(QStringLiteral("attica_kde"));
-    PlatformDependent * ret = qobject_cast<PlatformDependent *>(loader.instance());
+    PlatformDependent *ret = qobject_cast<PlatformDependent *>(loader.instance());
 
     return ret ? ret : new QtPlatformDependent;
 }
@@ -87,12 +86,12 @@ void ProviderManager::clear()
 
 void ProviderManager::slotLoadDefaultProvidersInternal()
 {
-    const auto providerFiles  = d->m_internals->getDefaultProviderFiles();
+    const auto providerFiles = d->m_internals->getDefaultProviderFiles();
     for (const QUrl &url : providerFiles) {
         addProviderFile(url);
     }
     if (d->m_downloads.isEmpty()) {
-        emit defaultProvidersLoaded();
+        Q_EMIT defaultProvidersLoaded();
     }
 }
 
@@ -129,7 +128,7 @@ void ProviderManager::addProviderFile(const QUrl &url)
     } else {
         if (!d->m_downloads.contains(url.toString())) {
             QNetworkRequest req(url);
-            req.setAttribute(QNetworkRequest::FollowRedirectsAttribute, true);
+            req.setAttribute(QNetworkRequest::RedirectPolicyAttribute, QNetworkRequest::RedirectPolicy::NoLessSafeRedirectPolicy);
             QNetworkReply *reply = d->m_internals->get(req);
             qCDebug(ATTICA) << "executing" << Utils::toString(reply->operation()) << "for" << reply->url();
             connect(reply, &QNetworkReply::finished, this, [this, url]() {
@@ -144,10 +143,11 @@ void ProviderManager::fileFinished(const QString &url)
 {
     QNetworkReply *reply = d->m_downloads.take(url);
     if (reply) {
-        if (reply->error())
+        if (reply->error()) {
             Q_EMIT failedToLoad(QUrl(url), reply->error());
-        else
+        } else {
             parseProviderFile(QLatin1String(reply->readAll()), QUrl(url));
+        }
         reply->deleteLater();
     } else {
         Q_EMIT failedToLoad(QUrl(url), QNetworkReply::UnknownNetworkError);
@@ -218,12 +218,26 @@ void ProviderManager::parseProviderFile(const QString &xmlString, const QUrl &ur
                 }
             }
             if (!baseUrl.isEmpty()) {
-                //qCDebug(ATTICA) << "Adding provider" << baseUrl;
-                d->m_providers.insert(baseUrl, Provider(d->m_internals, baseUrl, name, icon,
-                                                        person, friendV, message, achievement, activity, content, fan, forum, knowledgebase,
-                                                        event, comment, registerUrl));
+                // qCDebug(ATTICA) << "Adding provider" << baseUrl;
+                d->m_providers.insert(baseUrl,
+                                      Provider(d->m_internals,
+                                               baseUrl,
+                                               name,
+                                               icon,
+                                               person,
+                                               friendV,
+                                               message,
+                                               achievement,
+                                               activity,
+                                               content,
+                                               fan,
+                                               forum,
+                                               knowledgebase,
+                                               event,
+                                               comment,
+                                               registerUrl));
                 d->m_providerTargets[url] = baseUrl;
-                emit providerAdded(d->m_providers.value(baseUrl));
+                Q_EMIT providerAdded(d->m_providers.value(baseUrl));
             }
         }
     }
@@ -233,7 +247,7 @@ void ProviderManager::parseProviderFile(const QString &xmlString, const QUrl &ur
     }
 
     if (d->m_downloads.isEmpty()) {
-        emit defaultProvidersLoaded();
+        Q_EMIT defaultProvidersLoaded();
     }
 }
 
@@ -275,14 +289,14 @@ void ProviderManager::authenticate(QNetworkReply *reply, QAuthenticator *auth)
         }
     }
 
-    //qCDebug(ATTICA) << "ProviderManager::authenticate" << baseUrl;
+    // qCDebug(ATTICA) << "ProviderManager::authenticate" << baseUrl;
 
     QString user;
     QString password;
     if (auth->user().isEmpty() && auth->password().isEmpty()) {
         if (d->m_internals->hasCredentials(baseUrl)) {
             if (d->m_internals->loadCredentials(baseUrl, user, password)) {
-                //qCDebug(ATTICA) << "ProviderManager::authenticate: loading authentication";
+                // qCDebug(ATTICA) << "ProviderManager::authenticate: loading authentication";
                 auth->setUser(user);
                 auth->setPassword(password);
                 return;
@@ -291,14 +305,14 @@ void ProviderManager::authenticate(QNetworkReply *reply, QAuthenticator *auth)
     }
 
     if (!d->m_authenticationSuppressed && d->m_internals->askForCredentials(baseUrl, user, password)) {
-        //qCDebug(ATTICA) << "ProviderManager::authenticate: asking internals for new credentials";
-        //auth->setUser(user);
-        //auth->setPassword(password);
+        // qCDebug(ATTICA) << "ProviderManager::authenticate: asking internals for new credentials";
+        // auth->setUser(user);
+        // auth->setPassword(password);
         return;
     }
 
     qWarning() << "ProviderManager::authenticate: No authentication credentials provided, aborting." << reply->url().toString();
-    emit authenticationCredentialsMissing(d->m_providers.value(baseUrl));
+    Q_EMIT authenticationCredentialsMissing(d->m_providers.value(baseUrl));
     reply->abort();
 }
 
@@ -313,4 +327,3 @@ void ProviderManager::initNetworkAccesssManager()
     connect(d->m_internals->nam(), &QNetworkAccessManager::authenticationRequired, this, &ProviderManager::authenticate);
     connect(d->m_internals->nam(), &QNetworkAccessManager::proxyAuthenticationRequired, this, &ProviderManager::proxyAuthenticationRequired);
 }
-
