@@ -1,48 +1,32 @@
 /*
     This file is part of KDE.
 
-    Copyright 2010 Sebastian Kügler <sebas@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-FileCopyrightText: 2010 Sebastian Kügler <sebas@kde.org>
 
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "projecttest.h"
 
-#include <QLabel>
+#include <QAction>
 #include <QListWidgetItem>
 #include <QMenu>
 #include <QMenuBar>
-#include <QAction>
 #include <QVBoxLayout>
 
 #include <QDebug>
 
-#include <itemjob.h>
-#include <listjob.h>
 #include <buildservice.h>
 #include <buildservicejob.h>
+#include <itemjob.h>
+#include <listjob.h>
 #include <provider.h>
-#include <project.h>
 
 using namespace Attica;
 
-ProjectTest::ProjectTest() : QMainWindow(),
-    m_mainWidget(nullptr)
+ProjectTest::ProjectTest()
+    : QMainWindow()
+    , m_mainWidget(nullptr)
 {
     m_mainWidget = new QWidget();
     setCentralWidget(m_mainWidget);
@@ -59,8 +43,7 @@ ProjectTest::ProjectTest() : QMainWindow(),
     connect(m_editor->build, &QAbstractButton::clicked, this, &ProjectTest::createBuildServiceJob);
     connect(m_editor->cancelJob, &QAbstractButton::clicked, this, &ProjectTest::cancelBuildServiceJob);
     connect(m_editor->updateJob, &QAbstractButton::clicked, this, &ProjectTest::updateCurrentProject);
-    connect(m_editor->buildServices, &QListWidget::currentItemChanged,
-            this, &ProjectTest::selectedBuildServiceChanged);
+    connect(m_editor->buildServices, &QListWidget::currentItemChanged, this, &ProjectTest::selectedBuildServiceChanged);
 
     QAction *a = new QAction(this);
     a->setText(QLatin1String("Quit"));
@@ -71,7 +54,8 @@ ProjectTest::ProjectTest() : QMainWindow(),
 }
 
 ProjectTest::~ProjectTest()
-{}
+{
+}
 
 void ProjectTest::initOcs()
 {
@@ -80,7 +64,7 @@ void ProjectTest::initOcs()
     m_pm.loadDefaultProviders();
     m_mainWidget->setEnabled(false);
     setStatus(QLatin1String("Loading providers..."));
-    //connect(m_serviceUpdates.data(), SIGNAL(mapped(QString)), SLOT(serviceUpdates(QString)));
+    // connect(m_serviceUpdates.data(), SIGNAL(mapped(QString)), SLOT(serviceUpdates(QString)));
 }
 
 void ProjectTest::providerAdded(const Attica::Provider &provider)
@@ -112,7 +96,6 @@ void ProjectTest::getProject(QString id)
     job->start();
     setStatus(QString(QLatin1String("Loading project %")).arg(id));
     m_mainWidget->setEnabled(false);
-
 }
 
 void ProjectTest::listProjects()
@@ -183,9 +166,9 @@ Project ProjectTest::uiToProject()
     project.setVersion(m_editor->version->text());
     project.setLicense(m_editor->license->text());
     project.setUrl(m_editor->url->text());
-    QStringList _d = m_editor->developers->text().split(QLatin1Char(','));
+    const QStringList _d = m_editor->developers->text().split(QLatin1Char(','));
     QStringList devs;
-    foreach (const QString &dev, _d) {
+    for (const QString &dev : _d) {
         devs << dev.trimmed();
     }
     project.setDevelopers(devs);
@@ -293,7 +276,8 @@ void ProjectTest::projectListResult(Attica::BaseJob *j)
         qDebug() << "Yay, no errors ...";
         QStringList projectIds;
 
-        foreach (const Project &p, listJob->itemList()) {
+        const auto itemList = listJob->itemList();
+        for (const Project &p : itemList) {
             m_projects[p.id()] = p;
             qDebug() << "New project:" << p.id() << p.name();
             output.append(QString(QLatin1String("<br />%1 (%2)")).arg(p.name(), p.id()));
@@ -319,13 +303,14 @@ void ProjectTest::buildServiceListResult(Attica::BaseJob *j)
 {
     qDebug() << "BuildService list job returned";
     QString output = QLatin1String("<b>BuildServices:</b>");
-    //m_mainWidget->setEnabled(true); // fixme: tab
+    // m_mainWidget->setEnabled(true); // fixme: tab
 
     if (j->metadata().error() == Metadata::NoError) {
         Attica::ListJob<BuildService> *listJob = static_cast<Attica::ListJob<BuildService> *>(j);
         qDebug() << "Yay, no errors ...";
 
-        foreach (const BuildService &bs, listJob->itemList()) {
+        const auto itemList = listJob->itemList();
+        for (const BuildService &bs : itemList) {
             m_buildServices[bs.id()] = bs;
             qDebug() << "New OBS:" << bs.id() << bs.name() << bs.url();
             output.append(QString(QLatin1String("<br />%1 (%2) at %3")).arg(bs.name(), bs.id(), bs.url()));
@@ -333,9 +318,8 @@ void ProjectTest::buildServiceListResult(Attica::BaseJob *j)
             new_bs->setData(Qt::UserRole, QVariant(bs.id()));
 
             m_editor->accountsServers->insertItem(0, bs.name(), bs.id());
-            //QListWidgetItem* new_bsa = new QListWidgetItem(bs.name(), m_editor->accountsServers);
-            //new_bsa->setData(Qt::UserRole, QVariant(bs.id()));
-
+            // QListWidgetItem* new_bsa = new QListWidgetItem(bs.name(), m_editor->accountsServers);
+            // new_bsa->setData(Qt::UserRole, QVariant(bs.id()));
         }
         if (listJob->itemList().isEmpty()) {
             output.append(QLatin1String("No OBS'en found."));
@@ -348,20 +332,21 @@ void ProjectTest::buildServiceListResult(Attica::BaseJob *j)
         output.append(QString(QLatin1String("Unknown Error: %1")).arg(j->metadata().message()));
     }
     qDebug() << output;
-    //setBuildStatus(output);
+    // setBuildStatus(output);
 }
 
 void ProjectTest::buildServiceJobListResult(Attica::BaseJob *j)
 {
     qDebug() << "BuildServiceJobList list job returned";
     QString output = QLatin1String("<b>BuildServiceJobs: </b>");
-    //m_mainWidget->setEnabled(true); // fixme: tab
+    // m_mainWidget->setEnabled(true); // fixme: tab
 
     if (j->metadata().error() == Metadata::NoError) {
         Attica::ListJob<BuildServiceJob> *listJob = static_cast<Attica::ListJob<BuildServiceJob> *>(j);
         qDebug() << "Yay, no errors. Items found:" << listJob->itemList().count();
 
-        foreach (const BuildServiceJob &bsj, listJob->itemList()) {
+        const auto itemList = listJob->itemList();
+        for (const BuildServiceJob &bsj : itemList) {
             m_buildServiceJobs[bsj.id()] = bsj;
             qDebug() << "New BuildServiceJob:" << bsj.id() << bsj.name() << bsj.target();
             output.append(QString(QLatin1String("<br />%1 (%2) for %3")).arg(bsj.name(), bsj.id(), bsj.target()));
@@ -379,7 +364,7 @@ void ProjectTest::buildServiceJobListResult(Attica::BaseJob *j)
         output.append(QString(QLatin1String("Unknown Error: %1")).arg(j->metadata().message()));
     }
     qDebug() << output;
-    //setBuildStatus(output);
+    // setBuildStatus(output);
 }
 
 void ProjectTest::selectedBuildServiceChanged(QListWidgetItem *current, QListWidgetItem *previous)
@@ -387,9 +372,9 @@ void ProjectTest::selectedBuildServiceChanged(QListWidgetItem *current, QListWid
     Q_UNUSED(previous)
     qDebug() << "current item changed to " << current->data(Qt::UserRole).toString();
     m_editor->targets->clear();
-    QList<Target> targetlist = m_buildServices[current->data(Qt::UserRole).toString()].targets();
-    foreach (const Target &t, targetlist) {
-        //m_editor->targets->insertItems(0, m_buildServices[current->data(Qt::UserRole).toString()].targets());
+    const QList<Target> targetlist = m_buildServices[current->data(Qt::UserRole).toString()].targets();
+    for (const Target &t : targetlist) {
+        // m_editor->targets->insertItems(0, m_buildServices[current->data(Qt::UserRole).toString()].targets());
         m_editor->targets->insertItem(0, t.name, t.id);
         // FIXME: target id.
         qDebug() << "target:" << t.name << t.id;
@@ -405,7 +390,8 @@ void ProjectTest::createBuildServiceJob()
     b.setTarget(m_editor->targets->itemData(m_editor->targets->currentIndex()).toString());
 
     ///*
-    qDebug() << "Create build job:" << m_editor->targets->itemData(m_editor->targets->currentIndex()).toString() << m_editor->targets->currentIndex() << m_editor->targets->itemData(m_editor->targets->currentIndex());
+    qDebug() << "Create build job:" << m_editor->targets->itemData(m_editor->targets->currentIndex()).toString() << m_editor->targets->currentIndex()
+             << m_editor->targets->itemData(m_editor->targets->currentIndex());
     qDebug() << "Project:" << b.projectId();
     qDebug() << "Target:" << b.target();
     qDebug() << "Buildservice:" << b.buildServiceId();
@@ -429,7 +415,7 @@ void ProjectTest::cancelBuildServiceJob()
 
 void ProjectTest::buildServiceJobCanceled(Attica::BaseJob *j)
 {
-    //m_mainWidget->setEnabled(true); // fixme: tab
+    // m_mainWidget->setEnabled(true); // fixme: tab
     QString output;
     if (j->metadata().error() == Metadata::NoError) {
         qDebug() << "job canceled.";
@@ -449,7 +435,7 @@ void ProjectTest::buildServiceJobCanceled(Attica::BaseJob *j)
 void ProjectTest::buildServiceJobCreated(Attica::BaseJob *j)
 {
     qDebug() << "JOB CREATED!!!!!!!!!!!!!!!!";
-    //m_mainWidget->setEnabled(true); // fixme: tab
+    // m_mainWidget->setEnabled(true); // fixme: tab
     QString output;
     if (j->metadata().error() == Metadata::NoError) {
         qDebug() << "job created. I think.";
@@ -486,4 +472,3 @@ void ProjectTest::updateCurrentProject()
     p.setId(currentProject());
     listBuildServiceJobs(p);
 }
-
